import { scaleLinear, axisLeft } from 'd3';
import { axes } from './axes';

export const viz = (
  svg,
  {
    xAxisLabelText,
    xAxisLabelOffset,
    yAxisLabelText,
    yAxisLabelOffset,
    marginLeft,
    marginTop,
    marginRight,
    marginBottom,
    width,
    height,
    innerRectFill,
    hoveredX,
    hoveredY,
  },
) => {
  const xScale = scaleLinear(
    [0, 100],
    [marginLeft, width - marginRight],
  );
  const yScale = scaleLinear(
    [0, 100],
    [height - marginBottom, marginTop],
  );

  const innerWidth = width - marginLeft - marginRight;
  const innerHeight = height - marginTop - marginBottom;

  svg
    .selectAll('rect')
    .data([null])
    .join('rect')
    .attr('x', marginLeft)
    .attr('y', marginTop)
    .attr('width', innerWidth)
    .attr('height', innerHeight)
    .attr('fill', innerRectFill);

  axes(svg, {
    width,
    height,
    xScale,
    xAxisLabelText,
    xAxisLabelOffset,
    yScale,
    yAxisLabelText,
    yAxisLabelOffset,
    marginLeft,
    marginBottom,
  });

  const [xMin, xMax] = xScale.range();
  const [yMax, yMin] = yScale.range();

  const showHoveredLines =
    hoveredX < xMax &&
    hoveredX > xMin &&
    hoveredY < yMax &&
    hoveredY > yMin;

  const x = hoveredX;
  const y = hoveredY;
  const hoveredLinesData = showHoveredLines
    ? [
        { x1: x, y1: y, x2: x, y2: yMax },
        { x1: xMin, y1: y, x2: x, y2: y },
      ]
    : [];

  svg
    .selectAll('line.hovered-line')
    .data(hoveredLinesData)
    .join('line')
    .attr('class', 'hovered-line')
    .attr('x1', (d) => d.x1)
    .attr('y1', (d) => d.y1)
    .attr('x2', (d) => d.x2)
    .attr('y2', (d) => d.y2)
    .attr('stroke', 'black');

  // console.log(xScale.invert(hoveredX));
};
