import { select, descending, pointer } from 'd3';
import { viz } from './viz';
import { data } from '@vspatel927/national-park-2022';
import { observeResize } from '@curran/2d9651a57dd5443783b0c3c8c47cdfcf'

const nameColumn = 'Park_Name';
const visitorColumn = 'People';
// Take the top n parks by visitors
const n = 6;

const sortedData = data.sort((a, b) =>
  descending(a[visitorColumn], b[visitorColumn]),
);

const topNData = sortedData.slice(0, n);

export const main = (container, { state, setState }) => {
  const dimensions = observeResize({
    state,
    setState,
    container,
  });

  if (dimensions === null) return;

  const { width, height } = dimensions;

  const svg = select(container)
    .selectAll('svg')
    .data([null])
    .join('svg')
    .attr('width', width)
    .attr('height', height)
    .on('mousemove', (event) => {
      const [hoveredX, hoveredY] = pointer(event);
      setState((state) => ({
        ...state,
        hoveredX,
        hoveredY,
      }));
    });

  // The hovered mouse coordinates.
  // These may be `undefined`.
  const { hoveredX, hoveredY } = state;

  viz(svg, {
    data: topNData,
    xValue: (d) => d[nameColumn],
    xAxisLabelText: 'Park',
    xAxisLabelOffset: 38,
    yValue: (d) => d[visitorColumn],
    yAxisLabelText: 'Visitors',
    yAxisLabelOffset: 17,
    innerRectFill: '#E8E8E8',
    padding: 12 / 100,
    marginTop: 8,
    marginBottom: 42,
    marginLeft: 74,
    marginRight: 20,
    width,
    height,
    fontSize: '4px',
    hoveredX,
    hoveredY,
    container
  });

  // Sample row (d):
  // {
  //   "species": "Adelie",
  //   "island": "Torgersen",
  //   "bill_length_mm": 39.1,
  //   "bill_depth_mm": 18.7,
  //   "flipper_length_mm": 181,
  //   "body_mass_g": 3750,
  //   "sex": "male",
  //   "year": "2007"
  // }
};
