import {
  scaleLinear,
  scaleBand,
  axisLeft,
  max,
  select,
  selectAll,
} from 'd3';
import {
  xAxis,
  yAxis,
  xAxisLabel,
  yAxisLabel,
  axes,
} from '@curran/2d9651a57dd5443783b0c3c8c47cdfcf';

export const viz = (
  svg,
  {
    data,
    xValue,
    xAxisLabelText,
    xAxisLabelOffset,
    yValue,
    yAxisLabelText,
    yAxisLabelOffset,
    marginLeft,
    marginTop,
    marginRight,
    marginBottom,
    width,
    height,
    innerRectFill,
    padding,
    fontSize,
    hoveredX,
    hoveredY,
    container,
  },
) => {
  const xScale = scaleBand(data.map(xValue), [
    marginLeft,
    width - marginRight,
  ]).padding(padding);
  const yScale = scaleLinear(
    [0, max(data, yValue)],
    [height - marginBottom, marginTop],
  );

  const innerWidth = width - marginLeft - marginRight;
  const innerHeight = height - marginTop - marginBottom;

  const tooltip = select('body')
    .append('div')
    .attr('class', 'tooltip')
    .style('opacity', 0);

  svg
    .selectAll('rect.inner-rectangle')
    .data([null])
    .join('rect')
    .attr('class', 'inner-rectangle')
    .attr('x', marginLeft)
    .attr('y', marginTop)
    .attr('width', innerWidth)
    .attr('height', innerHeight)
    .attr('fill', innerRectFill);

  // Axes
  axes(svg, {
    width,
    height,
    xScale,
    xAxisLabelText,
    xAxisLabelOffset,
    yScale,
    yAxisLabelText,
    yAxisLabelOffset,
    marginLeft,
    marginBottom,
  });

  // Bars
  svg
    .selectAll('rect.mark')
    .data(data)
    .join('rect')
    .attr('class', 'mark')
    .attr('x', (d) => xScale(xValue(d)))
    .attr('y', (d) => yScale(yValue(d)))
    .attr('width', xScale.bandwidth() - 10)
    .attr('height', (d) => yScale(0) - yScale(yValue(d)))
    .on('mouseover', function (event, d) {
      select(this).attr('opacity', '.1');
      tooltip
        .transition()
        .duration(1000)
        .style('opacity', 0.9);
      tooltip
        .html(
          `Park: ${d['Park_Name']} <br> Visitors: ${d['People']}`,
        )
        .style('position', 'fixed')
        .style('left', event.pageX + 10 + 'px')
        .style('top', event.pageY + 10 + 'px')
        .style('background', '#ffffff');
    })
    // Hide tooltip on mouseout
    .on('mouseout', function () {
      select(this).attr('opacity', '1');
      selectAll('.tooltip').remove();
    });
};
